#!/bin/bash

echo "Daily maintenance starting: `date`"
# Delete tiles in zoomlevel 13-14 that are older than 336 hours = 14 days
sudo -u tirex -- /home.local/osm/bin/osmtilecleanup.pl --zoom 13-14 --action delete --rmemptydirs --minage 336 /var/lib/tirex/tiles/osm
sudo -u tirex -- /home.local/osm/bin/osmtilecleanup.pl --zoom 13-14 --action delete --rmemptydirs --minage 336 /var/lib/tirex/tiles/osmde
sudo -u tirex -- /home.local/osm/bin/osmtilecleanup.pl --zoom 13-14 --action delete --rmemptydirs --minage 336 /var/lib/tirex/tiles/osmhd
# Delete tiles in zoomlevel 15-20 that are older than 168 hours =  7 days
sudo -u tirex -- /home.local/osm/bin/osmtilecleanup.pl --zoom 15-20 --action delete --rmemptydirs --minage 168 /var/lib/tirex/tiles/osm
sudo -u tirex -- /home.local/osm/bin/osmtilecleanup.pl --zoom 15-20 --action delete --rmemptydirs --minage 168 /var/lib/tirex/tiles/osmde
sudo -u tirex -- /home.local/osm/bin/osmtilecleanup.pl --zoom 15-20 --action delete --rmemptydirs --minage 168 /var/lib/tirex/tiles/osmhd
# Delete all tiles in our bicycle/lecture hall overlay that are older
# than 24 hours as these are REALLY cheap to regenerate on the fly.
sudo -u tirex -- /home.local/osm/bin/osmtilecleanup.pl --zoom 10-20 --action delete --rmemptydirs --minage 24 /var/lib/tirex/tiles/rrze-ovl
# Regenerate a part of zoomlevel 0-12 tiles. There are at most 350000 such tiles.
# At 5000 a day, it'll take 70 days to regenerate all. As they hardly ever change, that should be fine.
export PRIO=31
# unrz191 2015-09-11: reduce number of 5000 because we have deleted a lot of tiles that are cheap to rerender.
/home.local/osm/bin/osmtilecleanup.pl --zoom  0-12 --action rerender \
                                      --limit 2000 --rrs /home.local/osm/bin/osmrerenderwrapper.sh /var/lib/tirex/tiles/osm
/home.local/osm/bin/osmtilecleanup.pl --zoom  0-12 --action rerender \
                                      --limit 2000 --rrs /home.local/osm/bin/osmrerenderwrapper-osmde.sh /var/lib/tirex/tiles/osmde
/home.local/osm/bin/osmtilecleanup.pl --zoom  0-12 --action rerender \
                                      --limit 2000 --rrs /home.local/osm/bin/osmrerenderwrapper-osmhd.sh /var/lib/tirex/tiles/osmhd
# Regenerate (part of) zoomlevel 13-14 tiles. Some of these are pretty expensive, so
# we rather rerender them scheduled than when they change (usually they really don't,
# it is 99 percent false alerts).
/home.local/osm/bin/osmtilecleanup.pl --zoom  13-14 --action rerender \
                                      --limit 1000 --rrs /home.local/osm/bin/osmrerenderwrapper.sh /var/lib/tirex/tiles/osm
/home.local/osm/bin/osmtilecleanup.pl --zoom  13-14 --action rerender \
                                      --limit 1000 --rrs /home.local/osm/bin/osmrerenderwrapper-osmde.sh /var/lib/tirex/tiles/osmde
/home.local/osm/bin/osmtilecleanup.pl --zoom  13-14 --action rerender \
                                      --limit 1000 --rrs /home.local/osm/bin/osmrerenderwrapper-osmhd.sh /var/lib/tirex/tiles/osmhd
# Update tile stats for munin
tirex-tiledir-check --stats=/var/lib/tirex/stats/tiles-osm.stats osm
tirex-tiledir-check --stats=/var/lib/tirex/stats/tiles-osmde.stats osmde
tirex-tiledir-check --stats=/var/lib/tirex/stats/tiles-osmhd.stats osmhd

DOW=`/bin/date '+%w'`
if [ "$DOW" == "6" -o "$DOW" == "3" ] ; then
	echo "Time to vacuum the databse... This will take a few hours."
	# Vacuum the database. This can take hours. Possibly better just once per week?
	time psql --dbname=osm -c 'vacuum verbose analyze'
fi

# Rerender Erlangen / Nuernberg. Around 4000 tiles, takes around 30 minutes.
tirex-batch --prio=${PRIO} --expire=+14400 map=osm bbox=10.93,49.37,11.14,49.63 z=13-19
tirex-batch --prio=${PRIO} --expire=+14400 map=osmde bbox=10.93,49.37,11.14,49.63 z=13-19
tirex-batch --prio=${PRIO} --expire=+14400 map=osmhd bbox=10.93,49.37,11.14,49.63 z=13-19

echo "Daily maintenance finished: `date`"

